@@ -1,5 +1,5 @@
 /* This file is part of GNU Pies.
-   Copyright (C) 2007-2022 Sergey Poznyakoff
+   Copyright (C) 2007-2025 Sergey Poznyakoff
 
    GNU Pies is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -358,7 +358,13 @@ input_append (struct input *inp, char c)
 		      logmsg (LOG_ERR, _("protocol error"));
 		      return 400;
 		    }
-		  inp->input_state = is_content;
+		  if (inp->input_content_length == 0)
+		    {
+		      inp->input_state = is_end;
+		      return 200;
+		    }
+		  else
+		    inp->input_state = is_content;
 		}
 	      else
 		{
@@ -1923,7 +1929,7 @@ fun_stop (struct json_value *result, struct prog *prog)
   if (!prog->active)
     {      
       json_object_set_string (result, "status", "ER");
-      json_object_set_string (result, "error_message", "already stopped");
+      json_object_set_string (result, "message", "already stopped");
     }
   else
     {
@@ -1940,7 +1946,7 @@ fun_start (struct json_value *result, struct prog *prog)
   if (!IS_COMPONENT (prog))
     {
       json_object_set_string (result, "status", "ER");
-      json_object_set_string (result, "error_message", "not a component");
+      json_object_set_string (result, "message", "not a component");
     }
   else
     {
@@ -1965,15 +1971,14 @@ fun_start (struct json_value *result, struct prog *prog)
 	  else
 	    {
 	      json_object_set_string (result, "status", "ER");
-	      /* FIXME: error message */
-	      json_object_set_string (result, "error_message",
-				      "can't open socket");
+	      /* FIXME: detailed error message */
+	      json_object_set_string (result, "message", "can't open socket");
 	    }
 	  break;
       
 	default:
 	  json_object_set_string (result, "status", "ER");
-	  json_object_set_string (result, "error_message", "already running");
+	  json_object_set_string (result, "message", "already running");
 	  return 0;
 	}
       prog->active = 1;
@@ -1987,12 +1992,12 @@ fun_restart (struct json_value *result, struct prog *prog)
   if (!IS_COMPONENT (prog))
     {
       json_object_set_string (result, "status", "ER");
-      json_object_set_string (result, "error_message", "not a component");
+      json_object_set_string (result, "message", "not a component");
     }
   else if (!prog->active)
     {
       json_object_set_string (result, "status", "ER");
-      json_object_set_string (result, "error_message", "not active");
+      json_object_set_string (result, "message", "not active");
     }
   else
     {
@@ -2005,12 +2010,12 @@ fun_restart (struct json_value *result, struct prog *prog)
 	  
       	case status_listener:
 	  json_object_set_string (result, "status", "ER");
-	  json_object_set_string (result, "error_message", "not applicable");
+	  json_object_set_string (result, "message", "not applicable");
 	  break;
       
 	default:
 	  json_object_set_string (result, "status", "ER");
-	  json_object_set_string (result, "error_message", "not running");
+	  json_object_set_string (result, "message", "not running");
 	}
     }
   return 0;
@@ -2208,7 +2213,7 @@ res_runlevel (struct ctlio *io, enum http_method meth,
 	  else
 	    {
 	      json_object_set_string (io->output.reply, "status", "ER");
-	      json_object_set_string (io->output.reply, "error_message",
+	      json_object_set_string (io->output.reply, "message",
 				      "invalid runlevel value");
 	    }
 	}
@@ -2221,13 +2226,13 @@ res_runlevel (struct ctlio *io, enum http_method meth,
  *   ["RUNLEVEL=3", "CONSOLE=/dev/tty", ...]  
  * GET /environ/NAME     -     Get value of variable NAME
  *   { "status":"OK", "value":"..." }
- *   { "status":"ER", "error_message":"..." }
+ *   { "status":"ER", "message":"..." }
  * DELETE /environ/NAME  -     Unset variable
  *   { "status":"OK" }
- *   { "status":"ER", "error_message":"..." }
+ *   { "status":"ER", "message":"..." }
  * PUT /environ/NAME=VALUE -   Set variable 
  *   { "status":"OK" }
- *   { "status":"ER", "error_message":"..." }
+ *   { "status":"ER", "message":"..." }
  */
 static void
 env_reply (struct ctlio *io, int ok, int rc)
@@ -2379,7 +2384,7 @@ conf_delete_files (struct ctlio *io, struct json_value *json)
 	  if (val->type != json_string)
 	    {
 	      json_object_set_string (io->output.reply, "status", "ER");
-	      json_object_set_string (io->output.reply, "error_message",
+	      json_object_set_string (io->output.reply, "message",
 				      "malformed request");
 	      return;
 	    }
@@ -2403,7 +2408,7 @@ conf_delete_files (struct ctlio *io, struct json_value *json)
       if (fails == n)
 	{
 	  json_object_set_string (io->output.reply, "status", "ER");
-	  json_object_set_string (io->output.reply, "error_message",
+	  json_object_set_string (io->output.reply, "message",
 				  "no matching files found");
 	  json_value_free (reply);
 	}
@@ -2412,7 +2417,7 @@ conf_delete_files (struct ctlio *io, struct json_value *json)
 	  json_object_set_string (io->output.reply, "status", "OK");
 	  if (fails)
 	    {
-	      json_object_set_string (io->output.reply, "error_message",
+	      json_object_set_string (io->output.reply, "message",
 				      "some files not removed");
 	      json_object_set (io->output.reply, "result", reply);
 	    }
@@ -2478,7 +2483,7 @@ conf_reload (struct ctlio *io)
   if (pies_reread_config ())
     {
       json_object_set_string (io->output.reply, "status", "ER");
-      json_object_set_string (io->output.reply, "error_message",
+      json_object_set_string (io->output.reply, "message",
 			      "configuration syntax error");
     }
   else
